@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is kernel build script for ubuntu 9.10's 2.6.31 kernel.
+# This is kernel build script for ubuntu 8.10's 2.6.27 kernel.
 #
 
 die () {
@@ -9,7 +9,7 @@ die () {
 }
 
 #VERSION=`uname -r | cut -d - -f 1,2`
-VERSION=`apt-cache search ^linux-image-2.6.31-..- | cut -b 13-21 | awk ' { print $1 }' | sort -r | uniq | head -n 1`
+VERSION=`apt-cache search ^linux-image-2.6.27-..- | cut -b 13-21 | awk ' { print $1 }' | sort -r | uniq | head -n 1`
 export CONCURRENCY_LEVEL=`grep -c '^processor' /proc/cpuinfo` || die "Can't export."
 
 apt-get -y install wget
@@ -17,9 +17,9 @@ apt-get -y install wget
 # Download TOMOYO Linux patches.
 mkdir -p /usr/src/rpm/SOURCES/
 cd /usr/src/rpm/SOURCES/ || die "Can't chdir to /usr/src/rpm/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.0-20101111.tar.gz ]
+if [ ! -r ccs-patch-1.8.0-20101122.tar.gz ]
 then
-    wget -O ccs-patch-1.8.0-20101111.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.0-20101111.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.0-20101122.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.0-20101122.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
@@ -28,14 +28,16 @@ apt-get install fakeroot build-essential || die "Can't install packages."
 apt-get build-dep linux-image-${VERSION}-generic || die "Can't install packages."
 apt-get source linux-image-${VERSION}-generic || die "Can't install kernel source."
 apt-get install linux-headers-${VERSION} || die "Can't install packages."
+apt-get build-dep linux-restricted-modules-${VERSION}-generic || die "Can't install packages."
+apt-get source linux-restricted-modules-${VERSION}-generic || die "Can't install kernel source."
 
 # Apply patches and create kernel config.
-cd linux-2.6.31/ || die "Can't chdir to linux-2.6.31/ ."
-tar -zxf /usr/src/rpm/SOURCES/ccs-patch-1.8.0-20101111.tar.gz || die "Can't extract patch."
-patch -p1 < patches/ccs-patch-2.6.31-ubuntu-9.10.diff || die "Can't apply patch."
+cd linux-2.6.27/ || die "Can't chdir to linux-2.6.27/ ."
+tar -zxf /usr/src/rpm/SOURCES/ccs-patch-1.8.0-20101122.tar.gz || die "Can't extract patch."
+patch -p1 < patches/ccs-patch-2.6.27-ubuntu-8.10.diff || die "Can't apply patch."
 rm -fR patches/ specs/ || die "Can't delete patch."
 for i in `find debian.master/ -type f -name '*generic*'`; do cp -p $i `echo $i | sed -e 's/generic/ccs/g'`; done
-for i in debian.master/config/*/config.common.*; do cat config.ccs >> $i; done
+for i in debian.master/config/*/config; do cat config.ccs >> $i; done
 rm debian.master/control.stub || die "Can't delete control.stub."
 make -f debian.master/rules debian.master/control.stub || die "Can't update control.stub."
 rm debian/control || die "Can't delete control."
@@ -45,7 +47,7 @@ debian/rules debian/control || die "Can't update control."
 patch -p0 << "EOF" || die "Can't patch link-headers."
 --- debian.master/scripts/link-headers
 +++ debian.master/scripts/link-headers
-@@ -39,4 +39,17 @@
+@@ -37,4 +37,17 @@
  done
  )
  
@@ -69,6 +71,14 @@ EOF
 debian/rules binary-headers || die "Failed to build kernel package."
 debian/rules binary-debs flavours=ccs || die "Failed to build kernel package."
 
+# Install header package for compiling additional modules.
+dpkg -i /usr/src/linux-headers-*-ccs*.deb || die "Can't install packages."
+cd /usr/src/linux-restricted-modules-2.6.27/ || die "Can't chdir to /usr/src/linux-restricted-modules-2.6.27/ ."
+for i in `find debian/ -type f -name '*generic*'`; do cp -p $i `echo $i | sed -e 's/generic/ccs/g'`; done
+touch debian/control.stub.in || die "Can't touch control."
+debian/rules debian/control || die "Can't run control."
+debian/rules binary-arch arch=i386 flavours=ccs || die "Failed to build kernel package."
+
 # Generate meta packages.
 cd /usr/src/
 rm -fR linux-meta-*/
